@@ -7,6 +7,8 @@ from typing import List, Optional
 from wads import pkg_path_names, root_dir, wads_configs, wads_configs_file
 from wads import pkg_join as wads_join
 from wads.util import mk_conditional_logger
+from wads.pack import write_configs
+from wads.licensing import license_body
 
 # from wads.pack_util import write_configs
 
@@ -87,10 +89,10 @@ def populate_pkg_dir(
     :return:
 
     """
-    # TODO: Test this defaults_from thing!
+
     args_defaults = dict()
     if defaults_from is not None:
-        if defaults_from == 'user_input':
+        if defaults_from == 'user_input':  # TODO: Implement!
             args_defaults = dict()  # ... and then fill with user input
             raise NotImplementedError(
                 'Not immplemented yet'
@@ -153,7 +155,9 @@ def populate_pkg_dir(
         install_requires=install_requires,
     )
     kwargs = {k: v for k, v in kwargs.items() if v is not None}
-    configs = dict(name=name, **configs, **kwargs, **args_defaults)
+    # configs = dict(name=name, **configs, **kwargs, **args_defaults)
+    configs = dict(name=name, **args_defaults, **configs, **kwargs)
+
     kwargs['description-file'] = kwargs.pop('description_file', '')
 
     assert (
@@ -182,16 +186,12 @@ def populate_pkg_dir(
             fp.write(content)
 
     if should_update('setup.cfg'):
-        from wads.pack import write_configs
-
         _clog("... making a 'setup.cfg'")
         if 'pkg-dir' in configs:
             del configs['pkg-dir']
         write_configs(pjoin(''), configs)
 
     if should_update('LICENSE'):
-        from wads.licensing import license_body
-
         _license_body = license_body(configs['license'])
         save_txt_to_pkg('LICENSE', _license_body)
 
